@@ -56,7 +56,30 @@ use Carp qw/croak carp confess cluck/;
 use Scalar::Util qw/looks_like_number blessed reftype/;
 use Unicode::UTF8 qw/decode_utf8 valid_utf8/;
 use B;
-our $VERSION = '0.29_01';
+our $VERSION = '0.29_02';
+
+sub create_json
+{
+    my ($input, %options) = @_;
+    my $jc = bless {
+	output => '',
+    };
+    $jc->{_strict} = !! $options{strict};
+    my $error = create_json_recursively ($jc, $input);
+    if ($error) {
+	$jc->user_error ($error);
+	delete $jc->{output};
+	return undef;
+    }
+    return $jc->{output};
+}
+
+sub create_json_strict
+{
+    my ($input, %options) = @_;
+    $options{strict} = 1;
+    return create_json ($input, %options);
+}
 
 # http://stackoverflow.com/questions/1185822/how-do-i-create-or-test-for-nan-or-infinity-in-perl#1185828
 
@@ -466,29 +489,6 @@ sub user_error
     }
 }
 
-sub create_json
-{
-    my ($input, %options) = @_;
-    my $jc = bless {
-	output => '',
-    };
-    $jc->{_strict} = !! $options{strict};
-    my $error = create_json_recursively ($jc, $input);
-    if ($error) {
-	$jc->user_error ($error);
-	delete $jc->{output};
-	return undef;
-    }
-    return $jc->{output};
-}
-
-sub create_json_strict
-{
-    my ($input, %options) = @_;
-    $options{strict} = 1;
-    return create_json ($input, %options);
-}
-
 sub new
 {
     return bless {
@@ -619,8 +619,70 @@ sub JSON::Create::PP::sort
 
 sub set
 {
-    # This is pure Perl in JSON::Create.
-    JSON::Create::set (@_);
+    my ($jc, %args) = @_;
+    for my $k (keys %args) {
+	my $value = $args{$k};
+
+	# Options are in alphabetical order
+
+	if ($k eq 'bool') {
+	    $jc->bool (@$value);
+	    next;
+	}
+	if ($k eq 'cmp') {
+	    $jc->cmp ($value);
+	    next;
+	}
+	if ($k eq 'downgrade_utf8') {
+	    $jc->downgrade_utf8 ($value);
+	    next;
+	}
+	if ($k eq 'escape_slash') {
+	    $jc->escape_slash ($value);
+	    next;
+	}
+	if ($k eq 'fatal_errors') {
+	    $jc->fatal_errors ($value);
+	    next;
+	}
+	if ($k eq 'indent') {
+	    $jc->indent ($value);
+	    next;
+	}
+	if ($k eq 'no_javascript_safe') {
+	    $jc->no_javascript_safe ($value);
+	    next;
+	}
+	if ($k eq 'non_finite_handler') {
+	    $jc->non_finite_handler ($value);
+	    next;
+	}
+	if ($k eq 'obj_handler') {
+	    $jc->obj_handler ($value);
+	    next;
+	}
+	if ($k eq 'replace_bad_utf8') {
+	    $jc->replace_bad_utf8 ($value);
+	    next;
+	}
+	if ($k eq 'sort') {
+	    $jc->sort ($value);
+	    next;
+	}
+	if ($k eq 'strict') {
+	    $jc->strict ($value);
+	    next;
+	}
+	if ($k eq 'unicode_upper') {
+	    $jc->unicode_upper ($value);
+	    next;
+	}
+	if ($k eq 'validate') {
+	    $jc->validate ($value);
+	    next;
+	}
+	warn "Unknown option '$k'";
+    }
 }
 
 sub type_handler
